%define srcname pykickstart

# Disable tests by default because they fail to run inside mock builds
# at the moment, but can run locally.  To build and run tests, do:
#     rpmbuild -ba --with runtests python-kickstart.spec
%bcond_with runtests

Name:		python-kickstart
Version:	3.52
Release:	%mkrel 2
License:	GPLv2 and MIT
Group:		Development/Python
Summary:	Python library and tools for manipulating kickstart files
URL:		https://fedoraproject.org/wiki/pykickstart
Source0:	https://github.com/pykickstart/pykickstart/archive/refs/tags/r%{version}.tar.gz

BuildArch:	noarch

BuildRequires:	gettext
BuildRequires:	make
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools
BuildRequires:	python3-requests
BuildRequires:	python3-six

%if %{with runtests}
BuildRequires:	python3-coverage
BuildRequires:	python3-pytest
%endif

%description
Python library and tools for manipulating kickstart files

# Pykickstart utilities
%package utils
Summary:	Python utilities for manipulating kickstart files
Group:		Development/Python
# Fedora package name for this subpackage...
Provides:       pykickstart = %{version}-%{release}
Requires:	python3-kickstart = %{version}-%{release}

%description utils
Python utilities for manipulating kickstart files.

# Python 3 library
%package -n python3-kickstart
Summary:	Python 3 library for manipulating kickstart files
Group:		Development/Python
%{?python_provide:%python_provide python3-kickstart}
%{?python_provide:%python_provide python3-pykickstart}
Provides:       python3-pykickstart = %{version}-%{release}
Requires: 	python3-six
Requires: 	python3-requests

%description -n python3-kickstart
Python 3 library for manipulating kickstart files.
The binaries are found in the python-kickstart-utils package.

%prep
%autosetup -n %{srcname}-r%{version} -p1


%build
make PYTHON=%{__python3}


%install
%make_install PYTHON=%{__python3}

%if %{with runtests}
%check
make PYTHON=%{__python3} test
%endif

%files utils
%license COPYING
%doc README.rst
%doc data/kickstart.vim
%{_bindir}/ksvalidator
%{_bindir}/ksflatten
%{_bindir}/ksverdiff
%{_bindir}/ksshell
%{_mandir}/man1/*

%files -n python3-kickstart
%doc docs/2to3
%doc docs/programmers-guide
%doc docs/kickstart-docs.rst
%{python3_sitelib}/pykickstart/
%{python3_sitelib}/pykickstart*.egg-info


%changelog
* Sun Mar 02 2025 wally <wally> 3.52-2.mga10
+ Revision: 2158380
- rebuild for python3.13

* Sat Feb 17 2024 papoteur <papoteur> 3.52-1.mga10
+ Revision: 2042091
- new version 3.52

* Tue Mar 29 2022 umeabot <umeabot> 3.30-3.mga9
+ Revision: 1832177
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 3.30-2.mga9
+ Revision: 1782762
- Rebuild for python-3.10

* Wed Mar 31 2021 ngompa <ngompa> 3.30-1.mga9
+ Revision: 1712105
- Rebase to 3.30

* Sun Feb 16 2020 umeabot <umeabot> 3.18-4.mga8
+ Revision: 1531949
- Mageia 8 Mass Rebuild

* Sun Sep 15 2019 tv <tv> 3.18-3.mga8
+ Revision: 1441429
- rebuild for python-3.8
- drop python2 subpkg

* Sat Jan 05 2019 wally <wally> 3.18-2.mga7
+ Revision: 1349828
- rebuild for python3.7

* Sat Nov 24 2018 ngompa <ngompa> 3.18-1.mga7
+ Revision: 1333711
- Rebase to pykickstart 3.18
- Add compatibility Provides matching Fedora package names
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild

* Sun Aug 06 2017 ngompa <ngompa> 2.37-1.mga7
+ Revision: 1137520
- Upgrade to 2.37
+ pterjan <pterjan>
- Rebuild for python 3.6

* Sun Nov 27 2016 ngompa <ngompa> 2.25-1.mga6
+ Revision: 1070454
- Update to 2.25
- Add patches from Fedora

* Wed Jan 13 2016 ngompa <ngompa> 2.24-1.mga6
+ Revision: 922387
- Add missing python3-mypy BR
- Add python(3)-coverage as BuildRequires
- Update to 2.24

* Sun Nov 15 2015 ngompa <ngompa> 2.20-1.mga6
+ Revision: 903327
- Upgrade to 2.20

* Wed Oct 15 2014 umeabot <umeabot> 1.77-8.mga5
+ Revision: 745860
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.77-7.mga5
+ Revision: 728942
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.77-6.mga5
+ Revision: 688111
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.77-4.mga4
+ Revision: 543757
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.77-3.mga4
+ Revision: 498829
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Jan 13 2013 umeabot <umeabot> 1.77-2.mga3
+ Revision: 379038
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 04 2011 anaselli <anaselli> 1.77-1.mga2
+ Revision: 175971
- imported package python-kickstart

